Learn R Programming

prefio (version 0.2.0)

pref_add_unranked: Complete preferences by adding unselected items as last place occurrances.

Description

Complete preferences by adding unselected items as last place occurrances.

Usage

pref_add_unranked(x)

Value

A new vector of preferences, with each selection starting with the corresponding selections made in x, but with all unranked items placed last.

Arguments

x

A vector of preferences.

Examples

Run this code
# Complete partial rankings by adding unranked items last
pref_add_unranked(preferences(c("a > b", "c > a", "b")))

Run the code above in your browser using DataLab