powered by
Keep only specified items from preferences.
pref_keep(x, items)
A new vector of preferences, but only containing items from each selection.
items
A vector of preferences.
preferences
The names of the items which should be kept for preferences in x.
x
# Keep only 'a' and 'c' pref_keep(preferences(c("a > b > c", "b > c > a")), c("a", "c"))
Run the code above in your browser using DataLab