Ordinal preferences can order every item, or they can order a subset. Some ordinal preference datasets will contain ties between items at a given rank. Hence, there are four distinct types of preferential data:
socStrict Orders - Complete List
soiStrict Orders - Incomplete List
tocOrders with Ties - Complete List
toiOrders with Ties - Incomplete List
pref_type(x, n_items = NULL)One of c("soc", "soi", "toc", "toi"), indicating the type of
preferences in x (with or without ties / complete or incomplete rankings).
A preferences object (or vector data representing preferences)
The number of items, needed to assess whether a selection is
complete or not. Defaults to nlevels(x) if x has class preferences,
otherwise defaults to the length of the longest preference.