powered by
Complete preferences by adding unselected items as last place occurrances.
pref_add_unranked(x)
A new vector of preferences, with each selection starting with the corresponding selections made in x, but with all unranked items placed last.
x
A vector of preferences.
preferences
# Complete partial rankings by adding unranked items last pref_add_unranked(preferences(c("a > b", "c > a", "b")))
Run the code above in your browser using DataLab