powered by
Remove specified items from preferences.
pref_omit(x, items)
A new vector of preferences, but with items removed from each selection.
items
A vector of preferences.
preferences
The names of the items which should be removed from the preferences in x.
x
# Remove 'b' pref_omit(preferences(c("a > b > c", "b > c > a")), "b") # Remove 'b' and 'd' pref_omit(preferences(c("a > b > c > d", "b > c > a > d")), c("b", "d"))
Run the code above in your browser using DataLab